about summary refs log tree commit homepage
path: root/lib/PublicInbox/Repobrowse.pm
diff options
context:
space:
mode:
authorEric Wong <e@80x24.org>2017-03-02 23:39:49 +0000
committerEric Wong <e@80x24.org>2017-03-02 23:39:49 +0000
commit16b1fbe36cc39a351ef9810b9018d36df833a941 (patch)
tree6a354e1ab5177993fb11bd5ae0e43400d66ffbce /lib/PublicInbox/Repobrowse.pm
parenta4df292ed39f6e02a7d57326f291583339cb562d (diff)
downloadpublic-inbox-16b1fbe36cc39a351ef9810b9018d36df833a941.tar.gz
This is shorter, and makes more sense as the endpoint
displays both tree listings and actual blob sources.
This will also make rewriting existing URLs from cgit
installations easier.
Diffstat (limited to 'lib/PublicInbox/Repobrowse.pm')
-rw-r--r--lib/PublicInbox/Repobrowse.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/PublicInbox/Repobrowse.pm b/lib/PublicInbox/Repobrowse.pm
index aad0e8ba..5ef9e59a 100644
--- a/lib/PublicInbox/Repobrowse.pm
+++ b/lib/PublicInbox/Repobrowse.pm
@@ -22,7 +22,7 @@ use strict;
 use warnings;
 use PublicInbox::RepoConfig;
 
-my %CMD = map { lc($_) => $_ } qw(Log Commit Tree Patch Blob Raw Tag Atom
+my %CMD = map { lc($_) => $_ } qw(Log Commit Src Patch Blob Raw Tag Atom
         Diff Snapshot);
 my %VCS = (git => 'Git');
 my %LOADED;
@@ -93,7 +93,7 @@ sub call {
         }
 
         # URL syntax: / repo [ / cmd [ / head [ / path ] ] ]
# cmd: log | commit | diff | tree | view | blob | snapshot
         # repo and path (@extra) may both contain '/'
         my $path_info = $env->{PATH_INFO};
         my (undef, $repo_path, @extra) = split(m{/+}, $path_info, -1);
@@ -93,7 +93,7 @@ sub call {
 
         # URL syntax: / repo [ / cmd [ / head [ / path ] ] ]
-        # cmd: log | commit | diff | tree | view | blob | snapshot
+        # cmd: log | commit | diff | src | view | blob | snapshot
         # repo and path (@extra) may both contain '/'
         my $path_info = $env->{PATH_INFO};